<?php

/**
 * @file Contains the page and form callbacks for the dpd module.
 */

/**
 * The settings form for the configuration panel.
 */
function commerce_dpd_settings_form($form, &$form_state) {
  $form['groups'] = array(
    '#type' => 'vertical_tabs'
  );

  $default_values = commerce_dpd_settings(array());

  if (commerce_dpd_check_api() === FALSE) {
    drupal_set_message(t('DPD API not reachable!'), 'warning', FALSE);
  }

  // Check if there is already the required tcpdf and fdpi library installed
  if (!commerce_dpd_get_library('tcpdf')) {
    drupal_set_message(t('You need to install TCPDF Library in order to use the Bulk Print Action to print multiple DPD Labels!'));
  }
  if (!commerce_dpd_get_library('fpdi')) {
    drupal_set_message(t('You need to install FPDI Library in order to use the Bulk Print Action to print multiple DPD Labels!'));
  }

  $form['commerce_dpd_api'] = array(
    '#type' => 'fieldset',
    '#title' => t('DPD API Settings'),
    '#collapsible' => TRUE,
    '#group' => 'groups',
    '#weight' => 1,
  );

  $form['commerce_dpd_mapping'] = array(
    '#type' => 'fieldset',
    '#title' => t('DPD Mapping'),
    '#collapsible' => TRUE,
    '#group' => 'groups',
    '#weight' => 2,
  );

  $form['commerce_dpd_label'] = array(
    '#type' => 'fieldset',
    '#title' => t('DPD Label Print'),
    '#collapsible' => TRUE,
    '#group' => 'groups',
    '#weight' => 3,
  );

  $form['commerce_dpd_api']['sandbox_live_option'] = array(
    '#type' => 'select',
    '#options' => array(
      'sandbox' => t('Sandbox'),
      'live' => t('Live'),
    ),
    '#title' => t('Choose Server'),
    '#description' => t('Contact DPD to obtain an API Partner Name.'),
    '#required' => TRUE,
    '#default_value' => isset($default_values['sandbox_live_option']) ? $default_values['sandbox_live_option'] : '',
  );

  $form['commerce_dpd_api']['api_partner_name'] = array(
    '#type' => 'textfield',
    '#title' => t('API Partner Name'),
    '#description' => t('Contact DPD to obtain an API Partner Name.'),
    '#required' => TRUE,
    '#default_value' => isset($default_values['api_partner_name']) ? $default_values['api_partner_name'] : '',
  );

  $form['commerce_dpd_api']['api_partner_token'] = array(
    '#type' => 'textfield',
    '#title' => t('API Partner Token'),
    '#description' => t('Contact DPD to obtain an API Partner Token.'),
    '#required' => TRUE,
    '#default_value' => isset($default_values['api_partner_token']) ? $default_values['api_partner_token'] : '',
  );

  $form['commerce_dpd_api']['cloud_user_id'] = array(
    '#type' => 'textfield',
    '#title' => t('Cloud User-ID'),
    '#description' => t('Contact DPD to obtain the Cloud User-ID.'),
    '#required' => TRUE,
    '#default_value' => isset($default_values['cloud_user_id']) ? $default_values['cloud_user_id'] : '',
  );
  $form['commerce_dpd_api']['user_token'] = array(
    '#type' => 'textfield',
    '#title' => t('User Token'),
    '#description' => t('Contact DPD to obtain an User Token.'),
    '#required' => TRUE,
    '#default_value' => isset($default_values['user_token']) ? $default_values['user_token'] : '',
  );

  $form['commerce_dpd_mapping']['salutation'] = array(
    '#type' => 'textfield',
    '#title' => t('Salutation'),
    '#description' => t('You may use tokens for this field.'),
    '#default_value' => isset($default_values['salutation']) ? $default_values['salutation'] : '',
  );
  /*
  $form['commerce_dpd_mapping']['phone'] = array(
    '#type' => 'textfield',
    '#title' => t('Phone'),
    '#description' => t('You may use tokens for this field.'),
    '#default_value' => isset($default_values['phone']) ? $default_values['phone'] : '',
  );
  */
  $form['commerce_dpd_mapping']['weight'] = array(
    '#type' => 'textfield',
    '#title' => t('Weight'),
    '#description' => t('You may use tokens for this field.'),
    '#default_value' => isset($default_values['weight']) ? $default_values['weight'] : '',
  );

  $form['commerce_dpd_mapping']['content'] = array(
    '#type' => 'textfield',
    '#title' => t('Content'),
    '#description' => t('You may use tokens for this field.'),
    '#default_value' => isset($default_values['content']) ? $default_values['content'] : '',
  );

  $form['commerce_dpd_mapping']['reference1'] = array(
    '#type' => 'textfield',
    '#title' => t('Reference1'),
    '#description' => t('You may use tokens for this field.'),
    '#default_value' => isset($default_values['reference1']) ? $default_values['reference1'] : '',
  );

  $form['commerce_dpd_mapping']['reference2'] = array(
    '#type' => 'textfield',
    '#title' => t('Reference2'),
    '#description' => t('You may use tokens for this field.'),
    '#default_value' => isset($default_values['reference2']) ? $default_values['reference2'] : '',
  );

  if (module_exists('token')) {
    $form['commerce_dpd_mapping']['token'] = array(
      '#type' => 'fieldset',
      '#title' => t('Click for Info of available Tokens'),
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
    );
    $form['commerce_dpd_mapping']['token']['token_help'] = array(
      '#theme' => 'token_tree',
      '#token_types' => array('commerce-product', 'commerce-order'),
    );
  }

  $form['commerce_dpd_label']['label_size'] = array(
    '#type' => 'select',
    '#options' => _commerce_dpd_label_size_options(),
    '#title' => t('Select Label Format'),
    '#description' => t('Choose your preferred Label format.'),
    '#required' => TRUE,
    '#default_value' => isset($default_values['label_size']) ? $default_values['label_size'] : '',
  );

  $form['commerce_dpd_label']['label_position'] = array(
    '#type' => 'select',
    '#options' => _commerce_dpd_label_start_position_options(),
    '#title' => t('Select Label Position'),
    '#description' => t('Choose your preferred Label position.'),
    '#required' => TRUE,
    '#default_value' => isset($default_values['label_position']) ? $default_values['label_position'] : '',
    '#states' => array(
      'visible' => array(   // action to take.
        ':input[name=label_size]' => array('value' => 'PDF_A4'),
      ),
    ),
  );

  $form['debug'] = array(
    '#type' => 'fieldset',
    '#title' => t('Debugging'),
    '#collapsible' => TRUE,
    '#collapsed' => !($default_values['debug_messages'] || $default_values['debug_log']),
  );
  $form['debug']['debug_log'] = array(
    '#type' => 'checkbox',
    '#title' => t('Log debug information to the system log'),
    '#default_value' => $default_values['debug_log'],
  );
  $form['debug']['debug_messages'] = array(
    '#type' => 'radios',
    '#title' => t('Show debug information'),
    '#default_value' => $default_values['debug_messages'],
    '#options' => array(
      0 => t('Never'),
      2 => t('In case of errors'),
      1 => t('Always'),
    ),
    '#description' => t('Debug information is only shown for Commerce DPD requests and is visible for users having the permission <a href="!url">%link</a>.', array(
        '%link' => t('Access the DPD API debugging messages'),
        '!url' => url('admin/people/permissions', array('fragment' => 'module-commerce_dpd'))
      )),
  );

  $form['actions']['#type'] = 'actions';
  $form['actions']['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save configuration'),
  );

  return $form;
}

/**
 * Validate callback for commerce_dpd_settings_form()
 */
function commerce_dpd_settings_form_validate($form, &$form_state) {
  $values = &$form_state['values'];
}

/**
 * Submit callback for commerce_dpd_settings_form()
 */
function commerce_dpd_settings_form_submit($form, &$form_state) {

  form_state_values_clean($form_state);
  $values = &$form_state['values'];

  // Get all current stored settings:
  $current_settings = commerce_dpd_settings(array());

  // Remove any values not in settings info:
  $settings = array_intersect_key($values, $current_settings);

  // Merge stored settings:
  $settings += $current_settings;

  // Save new merged settings:
  variable_set('commerce_dpd_settings', $settings);

  drupal_set_message(t('The configuration options have been saved.'));

}
